@@ -1,4 +1,3 @@
-import string
 from typing import Any, Dict, List
 
 from district42 import SchemaVisitor
@@ -23,17 +22,20 @@ from ._consts import (
     INT_MIN,
     LIST_LEN_MAX,
     LIST_LEN_MIN,
+    STR_ALPHABET,
     STR_LEN_MAX,
     STR_LEN_MIN,
 )
 from ._random import Random
+from ._regex_generator import RegexGenerator
 
 __all__ = ("Generator",)
 
 
 class Generator(SchemaVisitor[Any]):
-    def __init__(self, random: Random) -> None:
+    def __init__(self, random: Random, regex_generator: RegexGenerator) -> None:
         self._random = random
+        self._regex_generator = regex_generator
 
     def visit_none(self, schema: NoneSchema, **kwargs: Any) -> None:
         return None
@@ -63,17 +65,29 @@ class Generator(SchemaVisitor[Any]):
         if schema.props.value is not Nil:
             return schema.props.value
 
+        if schema.props.pattern is not Nil:
+            return self._regex_generator.generate(schema.props.pattern)
+
         if schema.props.len is not Nil:
             length = schema.props.len
         else:
             min_length = schema.props.min_len if (schema.props.min_len is not Nil) else STR_LEN_MIN
             max_length = schema.props.max_len if (schema.props.max_len is not Nil) else STR_LEN_MAX
+            if schema.props.substr is not Nil:
+                min_length = max(min_length, len(schema.props.substr))
+                max_length = max(max_length, len(schema.props.substr))
             length = self._random.random_int(min_length, max_length)
 
         if schema.props.alphabet is not Nil:
             alphabet = schema.props.alphabet
         else:
-            alphabet = string.printable
+            alphabet = STR_ALPHABET
+
+        if schema.props.substr is not Nil:
+            substr = schema.props.substr
+            generated = self._random.random_str(length - len(substr), alphabet)
+            offset = self._random.random_int(0, len(generated))
+            return generated[0:offset] + substr + generated[offset:]
 
         return self._random.random_str(length, alphabet)
 
